package com.jln.system.web.action.mqtt;

import com.alibaba.fastjson.JSONObject;
import com.google.gson.Gson;
import com.jln.common.enums.MqttEnum;
import com.jln.system.web.action.mqtt.pojo.dto.*;
import com.jln.system.web.action.mqtt.pojo.entity.EoStatistics;
import com.jln.system.web.action.mqtt.pojo.vo.StaticData;
import com.jln.system.web.action.mqtt.server.EoStatisticsService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.PropertySource;
import org.springframework.core.io.ClassPathResource;
import org.springframework.stereotype.Service;

import java.io.*;
import java.util.*;

@Service
@PropertySource("classpath:application.properties")
public class MqttStartClient {
    @Value("${carcertPath}")
    private String carcertPath;
    @Value("${sleepTime}")
    private Long sleepTime;

    @Value("${redis.separate}")
    private Integer separate;

    @Value("${public.flag}")
    private Boolean flag;
    @Value("${commonSk}")
    private String commonSk;


    @Autowired
    private Base64decrypt base64decrypt;

    @Autowired
    private EoStatisticsService eoStatisticsService;

    private static Logger logger = LoggerFactory.getLogger(MqttStartClient.class);

    /**
     * 大件坡口机器人01
     *
     * @param txtFile
     * @param skFileUrl
     * @param comparison
     * @param deviceId
     */
    public void djpk01StartLj(String txtFile, String skFileUrl, Map<String, String> comparison, String deviceId,XBMqttDataUtil xbMqttDataUtil) {
        try {

            //TODO 解析sk证书信息
            Map<String, Object> reportDto = resolveSk(skFileUrl);
            reportDto.put("productKey", "GrooveRobot");
            //实体类信息 从文件中查询基本信息
            Map<String, String> sites = readTxtFileToMap(txtFile);
            reportDto.put("clientUuid", sites.get("设备ID"));
            PkjqrReportDataDto pkjqrReportDataDto = new PkjqrReportDataDto();
            pkjqrReportDataDto.setDeviceID(sites.get("设备ID"));
            pkjqrReportDataDto.setCompanyNo(sites.get("公司编码"));
            pkjqrReportDataDto.setFactoryNo(sites.get("工厂编码"));
            pkjqrReportDataDto.setAssetNo(sites.get("资产编码"));
            pkjqrReportDataDto.setDeviceName(sites.get("设备名称"));
            pkjqrReportDataDto.setDeviceType(sites.get("设备类型"));
            pkjqrReportDataDto.setCncType(sites.get("系统型号"));
            pkjqrReportDataDto.setSerNum(sites.get("序列号"));
            pkjqrReportDataDto.setNcVer(sites.get("系统版本"));
            //设备状态统计
            EoStatistics eo = new EoStatistics();
            eo.setSb(deviceId+"01");
            //1 redis和mqtt分开
            if (separate == 1) {
                //2 redis和mqtt统一
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.pkjqr01SendString(comparison, deviceId, pkjqrReportDataDto, reportDto);
                    String json = new Gson().toJson(objectMap);
                    StaticData.data.put(deviceId+"01", objectMap);
                    xbMqttDataUtil.publish(json);
                    System.out.println("--------数据发送成功---------");
                    eoStatisticsService.isFlag(objectMap,eo);
                    Thread.sleep(sleepTime);
                }
            } else if (separate == 2) {
                //3 只发送redis
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.pkjqr01SendString(comparison, deviceId, pkjqrReportDataDto, reportDto);
                    StaticData.data.put(deviceId+"01", objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
                    Thread.sleep(sleepTime);
                }
            } else if (separate == 3) {
                //4 只发送mqtt
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.pkjqr01SendString(comparison, deviceId, pkjqrReportDataDto, reportDto);
                    String json = new Gson().toJson(objectMap);
                    try {
                        xbMqttDataUtil.publish(json);
                        eoStatisticsService.isFlag(objectMap,eo);
                        Thread.sleep(sleepTime);
                    } catch (Exception e) {
                        continue;
                    }
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 大件坡口机器人02
     *
     * @param txtFile
     * @param skFileUrl
     * @param comparison
     * @param deviceId
     */
    public void djpk02StartLj(String txtFile, String skFileUrl, Map<String, String> comparison, String deviceId,XBMqttDataUtil xbMqttDataUtil) {
        try {
            //TODO 解析sk证书信息
            Map<String, Object> reportDto = resolveSk(skFileUrl);
            reportDto.put("productKey", "GrooveRobot");
            //实体类信息 从文件中查询基本信息
            Map<String, String> sites = readTxtFileToMap(txtFile);
            reportDto.put("clientUuid", sites.get("设备ID"));
            PkjqrReportDataDto pkjqrReportDataDto = new PkjqrReportDataDto();
            pkjqrReportDataDto.setDeviceID(sites.get("设备ID"));
            pkjqrReportDataDto.setCompanyNo(sites.get("公司编码"));
            pkjqrReportDataDto.setFactoryNo(sites.get("工厂编码"));
            pkjqrReportDataDto.setAssetNo(sites.get("资产编码"));
            pkjqrReportDataDto.setDeviceName(sites.get("设备名称"));
            pkjqrReportDataDto.setDeviceType(sites.get("设备类型"));
            pkjqrReportDataDto.setCncType(sites.get("系统型号"));
            pkjqrReportDataDto.setSerNum(sites.get("序列号"));
            pkjqrReportDataDto.setNcVer(sites.get("系统版本"));
            //设备状态统计
            EoStatistics eo = new EoStatistics();
            eo.setSb(deviceId+"02");
            //1 redis和mqtt分开
            if (separate == 1) {
                //2 redis和mqtt统一
                while (true) {

                    Map<String, Object> objectMap = base64decrypt.pkjqr02SendString(comparison, deviceId, pkjqrReportDataDto, reportDto);
                    StaticData.data.put(deviceId+"02", objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
                    Thread.sleep(sleepTime);
                }
            } else if (separate == 2) {
                //3 只发送redis
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.pkjqr02SendString(comparison, deviceId, pkjqrReportDataDto, reportDto);
                    StaticData.data.put(deviceId+"02", objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
                    Thread.sleep(sleepTime);
                }
            } else if (separate == 3) {
                //4 只发送mqtt
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.pkjqr02SendString(comparison, deviceId, pkjqrReportDataDto, reportDto);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish( json);
                    eoStatisticsService.isFlag(objectMap,eo);
                    Thread.sleep(sleepTime);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 400折弯机
     * @param txtFile
     * @param skFileUrl
     * @param comparison
     * @param deviceId
     */
    public void zwj400(String txtFile, String skFileUrl, Map<String, String> comparison, String deviceId,XBMqttDataUtil xbMqttDataUtil) {
        try {
            //TODO 解析sk证书信息
            Map<String, Object> reportDto = resolveSk(skFileUrl);
            reportDto.put("productKey", "BendingMach");
            //实体类信息 从文件中查询基本信息
            Map<String, String> sites = readTxtFileToMap(txtFile);
            reportDto.put("clientUuid", sites.get("设备ID"));
            ZwjReportDataDto zwjReportDataDto = new ZwjReportDataDto();
            zwjReportDataDto.setDeviceID(sites.get("设备ID"));
            zwjReportDataDto.setCompanyNo(sites.get("公司编码"));
            zwjReportDataDto.setFactoryNo(sites.get("工厂编码"));
            zwjReportDataDto.setAssetNo(sites.get("资产编码"));
            zwjReportDataDto.setDeviceName(sites.get("设备名称"));
            zwjReportDataDto.setDeviceType(sites.get("设备类型"));
            zwjReportDataDto.setCncType(sites.get("系统型号"));
            zwjReportDataDto.setNcVer(sites.get("系统版本"));
            zwjReportDataDto.setMaxPres(sites.get("系统最大压力"));
            zwjReportDataDto.setTableSize(sites.get("工作台面尺寸"));
            //设备变量统计
            EoStatistics eo = new EoStatistics();
            eo.setSb(deviceId);
            //1 redis和mqtt分开
            if (separate == 1) {
                //2 redis和mqtt统一
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.zwjSendString(comparison, deviceId, zwjReportDataDto, reportDto);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
                    Thread.sleep(sleepTime);
                }
            } else if (separate == 2) {
                //3 只发送redis
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.zwjSendString(comparison, deviceId, zwjReportDataDto, reportDto);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
                    Thread.sleep(sleepTime);
                }
            } else if (separate == 3) {
                //4 只发送mqtt
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.zwjSendString(comparison, deviceId, zwjReportDataDto, reportDto);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
                    eoStatisticsService.isFlag(objectMap,eo);
                    Thread.sleep(sleepTime);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    /**
     * 800折弯机
     * @param txtFile
     * @param skFileUrl
     * @param comparison
     * @param deviceId
     */
    public void zwj800(String txtFile, String skFileUrl, Map<String, String> comparison, String deviceId,XBMqttDataUtil xbMqttDataUtil) {
        try {
            //TODO 解析sk证书信息
            Map<String, Object> reportDto = resolveSk(skFileUrl);
            reportDto.put("productKey", "BendingMach");
            //实体类信息 从文件中查询基本信息
            Map<String, String> sites = readTxtFileToMap(txtFile);
            reportDto.put("clientUuid", sites.get("设备ID"));
            Zwj800ReportDataDto zwjReportDataDto = new Zwj800ReportDataDto();
            zwjReportDataDto.setDeviceID(sites.get("设备ID"));
            zwjReportDataDto.setCompanyNo(sites.get("公司编码"));
            zwjReportDataDto.setFactoryNo(sites.get("工厂编码"));
            zwjReportDataDto.setAssetNo(sites.get("资产编码"));
            zwjReportDataDto.setDeviceName(sites.get("设备名称"));
            zwjReportDataDto.setDeviceType(sites.get("设备类型"));
            zwjReportDataDto.setCncType(sites.get("系统型号"));
            zwjReportDataDto.setNcVer(sites.get("系统版本"));
            zwjReportDataDto.setDeviceBrand(sites.get("设备品牌"));
            zwjReportDataDto.setMaxPres(sites.get("最大压力"));
            zwjReportDataDto.setTableSize(sites.get("工作台面尺寸"));
            zwjReportDataDto.setLimitUpl(sites.get("轴行程正限位"));
            zwjReportDataDto.setLimotDownl(sites.get("轴行程负限位"));
            //设备状态统计
            EoStatistics eo = new EoStatistics();
            eo.setSb(deviceId);
            //1 redis和mqtt分开
            if (separate == 1) {
                //2 redis和mqtt统一
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.zwj800SendString(comparison, deviceId, zwjReportDataDto, reportDto);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
                    Thread.sleep(sleepTime);
                }
            } else if (separate == 2) {
                //3 只发送redis
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.zwj800SendString(comparison, deviceId, zwjReportDataDto, reportDto);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
                    Thread.sleep(sleepTime);
                }
            } else if (separate == 3) {
                //4 只发送mqtt
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.zwj800SendString(comparison, deviceId, zwjReportDataDto, reportDto);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
                    eoStatisticsService.isFlag(objectMap,eo);
                    Thread.sleep(sleepTime);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    /**
     * 龙门铣
     * @param lmxBjTxt
     * @param skFileUrl
     * @param comparison
     * @param deviceId
     * @param bjxx
     */
    public void lmxStartLj(String lmxBjTxt, String skFileUrl, Map<String, List<String>> comparison, String deviceId, String bjxx,XBMqttDataUtil xbMqttDataUtil) {

        try {
            //TODO 解析sk证书信息
            Map<String, Object> reportDto = resolveSk(skFileUrl);
            //读取报警信息配置文件
            Map<String, String> bjxxMap = readTxtFileToMap(bjxx);
            reportDto.put("productKey", "CncMach");
            //实体类信息 从文件中查询基本信息
            Map<String, String> sites = readTxtFileToMap(lmxBjTxt);
            reportDto.put("clientUuid", sites.get("设备ID"));
            LmxReportDataDto lmxReportDataDto = new LmxReportDataDto();
            lmxReportDataDto.setDeviceID(sites.get("设备ID"));
            lmxReportDataDto.setNcVer(sites.get("系统版本"));
            lmxReportDataDto.setAxes(sites.get("伺服轴数"));
            lmxReportDataDto.setSpinNum(sites.get("主轴数"));
            lmxReportDataDto.setMaxSpeed(sites.get("主轴最高转速"));
            lmxReportDataDto.setDeviceName(sites.get("设备名称"));
            lmxReportDataDto.setDeviceBrand(sites.get("设备品牌"));
            lmxReportDataDto.setCompanyNo(sites.get("公司编码"));
            lmxReportDataDto.setFactoryNo(sites.get("工厂编码"));
            lmxReportDataDto.setAssetNo(sites.get("资产编码"));
            lmxReportDataDto.setCncType(sites.get("系统型号"));
            lmxReportDataDto.setDeviceType(sites.get("设备类型"));
            //设备变量统计
            EoStatistics eo = new EoStatistics();
            eo.setSb(deviceId);
            if (separate == 1) {
                    Map<String, Object> objectMap = base64decrypt.lmxSendString(comparison, deviceId, lmxReportDataDto, reportDto, bjxxMap);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
            } else if (separate == 2) {
                    Map<String, Object> objectMap = base64decrypt.lmxSendString(comparison, deviceId, lmxReportDataDto, reportDto, bjxxMap);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
            } else if (separate == 3) {
                    Map<String, Object> objectMap = base64decrypt.lmxSendString(comparison, deviceId, lmxReportDataDto, reportDto, bjxxMap);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
                    eoStatisticsService.isFlag(objectMap,eo);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }

    }

    /**
     * 平面钻
     * @param pmzBjTxt
     * @param skFileUrl
     * @param comparison
     * @param deviceId
     */
    public void pmzStartLj(String pmzBjTxt, String skFileUrl, Map<String, List<String>> comparison, String deviceId,XBMqttDataUtil xbMqttDataUtil) {
        try {
            //TODO 解析sk证书信息
            Map<String, Object> reportDto = resolveSk(skFileUrl);
            reportDto.put("productKey", "CncMach");
            //实体类信息 从文件中查询基本信息
            Map<String, String> sites = readTxtFileToMap(pmzBjTxt);
            reportDto.put("clientUuid", sites.get("设备ID"));
            PmzReportDataDto pmzReportDataDto = new PmzReportDataDto();
            pmzReportDataDto.setDeviceID(sites.get("设备ID"));
            pmzReportDataDto.setCompanyNo(sites.get("公司编码"));
            pmzReportDataDto.setFactoryNo(sites.get("工厂编码"));
            pmzReportDataDto.setAssetNo(sites.get("资产编码"));
            pmzReportDataDto.setDeviceName(sites.get("设备名称"));
            pmzReportDataDto.setDeviceType(sites.get("设备类型"));
            pmzReportDataDto.setCncType(sites.get("系统型号"));
            pmzReportDataDto.setNcVer(sites.get("系统版本"));
            pmzReportDataDto.setDeviceBrand(sites.get("设备品牌"));
            pmzReportDataDto.setMaxSpeed(sites.get("最大卷板速度"));
            //设备状态统计
            EoStatistics eo = new EoStatistics();
            eo.setSb(deviceId);
            if (separate == 1) {
                    Map<String, Object> objectMap = base64decrypt.pmzSendString(comparison, deviceId, pmzReportDataDto, reportDto);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
            } else if (separate == 2) {

                    Map<String, Object> objectMap = base64decrypt.pmzSendString(comparison, deviceId, pmzReportDataDto, reportDto);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
            } else if (separate == 3) {
                    Map<String, Object> objectMap = base64decrypt.pmzSendString(comparison, deviceId, pmzReportDataDto, reportDto);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
                    eoStatisticsService.isFlag(objectMap,eo);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * @param txtFileUrl     静态文件路径
     * @param skFileUrl      sk文件路径
     * @param comparison     scada中配置的点位
     * @param deviceId       设备标识
     */
    public void jgStartLj(String txtFileUrl, String skFileUrl, Map<String, String> comparison, String deviceId, XBMqttDataUtil xbMqttDataUtil) {
        try {
            //TODO 解析sk证书信息
            Map<String, Object> reportDto = resolveSk(skFileUrl);
            reportDto.put("productKey", "LaserCutMach"); // TODO 上报到客户那边数据中必要的参数值
            //解析设备txt文本获取静态属性值
            Map<String, String> sites = readTxtFileToMap(txtFileUrl);
            JgReportDataDto jgReportDataDto = new JgReportDataDto();
            if (!sites.isEmpty()) {
                reportDto.put("clientUuid", sites.get("设备ID"));  //TODO 上报到客户那边数据中必要的参数值
                jgReportDataDto.setDeviceID(sites.get("设备ID"));
                jgReportDataDto.setCompanyNo(sites.get("公司编码"));
                jgReportDataDto.setFactoryNo(sites.get("工厂编码"));
                jgReportDataDto.setAssetNo(sites.get("资产编码"));
                jgReportDataDto.setDeviceName(sites.get("设备名称"));
                jgReportDataDto.setDeviceType(sites.get("设备类型"));
                jgReportDataDto.setCncType(sites.get("系统型号"));
                jgReportDataDto.setNcVer(sites.get("系统版本"));
                jgReportDataDto.setDeviceBrand(sites.get("设备品牌"));
                jgReportDataDto.setSerNum(sites.get("序列号"));
            }
            EoStatistics eo = new EoStatistics();
            eo.setSb(deviceId);
            //1 redis和mqtt分开
            if (separate == 1) {
                //TODO 同时MQTT上报和推送前端数据
                    Map<String, Object> objectMap = base64decrypt.jgSendString(comparison, deviceId, jgReportDataDto, reportDto);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish( json);
            } else if (separate == 2) {
                // TODO  只推送前端数据
                    Map<String, Object> objectMap = base64decrypt.jgSendString(comparison, deviceId, jgReportDataDto, reportDto);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
            } else if (separate == 3) {
                //TODO  只发送mqtt
                    Map<String, Object> objectMap = base64decrypt.jgSendString(comparison, deviceId, jgReportDataDto, reportDto);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
                    eoStatisticsService.isFlag(objectMap,eo);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 梅塞尔
     * @param txtFile
     * @param skFileUrl
     * @param comparison
     * @param deviceId
     */
    public void msrStartLj(String txtFile, String skFileUrl, Map<String, List<String>> comparison, String deviceId,XBMqttDataUtil xbMqttDataUtil ) {
        try {
            //TODO 解析sk证书信息
            Map<String, Object> reportDto = resolveSk(skFileUrl);
            reportDto.put("productKey", "PlaCutMach");
            //实体类信息 从文件中查询基本信息
            Map<String, String> sites = readTxtFileToMap(txtFile);
            reportDto.put("clientUuid", sites.get("设备ID"));
            DlzReportDataDto dlzReportDataDto = new DlzReportDataDto();
            String[] ids = sites.get("设备ID").split("/");
            if ("mse52".equals(deviceId)) {
                dlzReportDataDto.setDeviceID(ids[0]);
            } else if ("mse53".equals(deviceId)) {
                //dlzReportDataDto.setDeviceID(ids[1]);
                dlzReportDataDto.setDeviceID(ids[0]);
            } else {
                dlzReportDataDto.setDeviceID(sites.get("设备ID"));
            }
            dlzReportDataDto.setCompanyNo(sites.get("公司编码"));
            dlzReportDataDto.setFactoryNo(sites.get("工厂编码"));
            dlzReportDataDto.setAssetNo(sites.get("资产编码"));
            dlzReportDataDto.setDeviceName(sites.get("设备名称"));
            dlzReportDataDto.setDeviceType(sites.get("设备类型"));
            dlzReportDataDto.setCncType(sites.get("系统型号"));
            dlzReportDataDto.setNcVer(sites.get("系统版本"));
            dlzReportDataDto.setDeviceBrand(sites.get("设备品牌"));
            //等离子电源型号=111
            dlzReportDataDto.setElePowerType(sites.get("等离子电源型号"));
            //最大空走速度=222
            dlzReportDataDto.setMaxIdleSpeed(sites.get("最大空走速度"));
            // 最大切割速度=333
            dlzReportDataDto.setMaxCutSpeed(sites.get("最大切割速度"));
            //切割零件范围=444
            dlzReportDataDto.setCutRange(sites.get("切割零件范围"));
            //割枪配置数量=555
            dlzReportDataDto.setCutGunNo(sites.get("割枪配置数量"));
            //各轴行程=666
            dlzReportDataDto.setAxisTrip(sites.get("各轴行程"));
            //定位精度=777
            dlzReportDataDto.setPosAcc(sites.get("定位精度"));
            //工作台面尺寸=888
            dlzReportDataDto.setWorkSize(sites.get("工作台面尺寸"));
            dlzReportDataDto.setCutGasType(sites.get("切割气体类型"));
            dlzReportDataDto.setProGasType(sites.get("保护气体类型"));
            dlzReportDataDto.setVoltage(sites.get("工作电压"));
            dlzReportDataDto.setAxisName(sites.get("轴名称"));
            dlzReportDataDto.setSerNum(sites.get("序列号"));
            //设备变量统计
            EoStatistics eo =new EoStatistics();
            eo.setSb(deviceId);
            //1 redis和mqtt分开
            if (separate == 1) {
                //2 redis和mqtt统一
                    Map<String, Object> objectMap = base64decrypt.msrSendString(comparison, deviceId, dlzReportDataDto, reportDto);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
            } else if (separate == 2) {
                //3 只发送redis
                    Map<String, Object> objectMap = base64decrypt.msrSendString(comparison, deviceId, dlzReportDataDto, reportDto);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
            } else if (separate == 3) {
                //4 只发送mqtt
                    Map<String, Object> objectMap = base64decrypt.msrSendString(comparison, deviceId, dlzReportDataDto, reportDto);
                    // objectMap.remove("reportedRedis");
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
                    eoStatisticsService.isFlag(objectMap,eo);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 智能行车
     * @param txtFile
     * @param skFileUrl
     * @param comparison
     * @param deviceId
     */
    public void znhcStartLj(String txtFile, String skFileUrl, Map<String, String> comparison, String deviceId,XBMqttDataUtil xbMqttDataUtil) {
        try {
            //TODO 解析sk证书信息
            Map<String, Object> reportDto = resolveSk(skFileUrl);
            reportDto.put("productKey", "SmartDrive");
            //实体类信息 从文件中查询基本信息
            Map<String, String> sites = readTxtFileToMap(txtFile);
            reportDto.put("clientUuid", sites.get("设备ID"));
            ZlhcReportDataDto zlhcReportDataDto = new ZlhcReportDataDto();
            zlhcReportDataDto.setDeviceID(sites.get("设备ID"));
            zlhcReportDataDto.setCompanyNo(sites.get("公司编码"));
            zlhcReportDataDto.setFactoryNo(sites.get("公司编码"));
            zlhcReportDataDto.setAssetNo(sites.get("资产编码"));
            zlhcReportDataDto.setDeviceName(sites.get("设备名称"));
            zlhcReportDataDto.setDeviceType(sites.get("设备类型"));
            zlhcReportDataDto.setCncType(sites.get("系统型号"));
            zlhcReportDataDto.setNcVer(sites.get("系统版本"));
            //设备变量统计
            EoStatistics eo = new EoStatistics();
            eo.setSb(deviceId);
            //1 redis和mqtt分开
            if (separate == 1) {
                //2 redis和mqtt统一
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.zlhcSendString(comparison, deviceId, zlhcReportDataDto, reportDto);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
                    Thread.sleep(sleepTime);
                }
            } else if (separate == 2) {
                //3 只发送redis
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.zlhcSendString(comparison, deviceId, zlhcReportDataDto, reportDto);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
                    Thread.sleep(sleepTime);
                }
            } else if (separate == 3) {
                //4 只发送mqtt
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.zlhcSendString(comparison, deviceId, zlhcReportDataDto, reportDto);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
                    eoStatisticsService.isFlag(objectMap,eo);
                    Thread.sleep(sleepTime);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 校平机
     * @param txtFile
     * @param skFileUrl
     * @param comparison
     * @param deviceId
     */
    public void xpjStartLj(String txtFile, String skFileUrl, Map<String, String> comparison, String deviceId, XBMqttDataUtil xbMqttDataUtil) {

        try {
            //TODO 解析sk证书信息
            Map<String, Object> reportDto = resolveSk(skFileUrl);
            reportDto.put("productKey", "ShapMach");
            //实体类信息 从文件中查询基本信息
            Map<String, String> sites = readTxtFileToMap(txtFile);
            reportDto.put("clientUuid", sites.get("设备ID"));
            XpjReportDataDto xpjReportDataDto = new XpjReportDataDto();
            xpjReportDataDto.setDeviceID(sites.get("设备ID"));
            xpjReportDataDto.setCompanyNo(sites.get("公司编码"));
            xpjReportDataDto.setFactoryNo(sites.get("工厂编码"));
            xpjReportDataDto.setAssetNo(sites.get("资产编码"));
            xpjReportDataDto.setDeviceName(sites.get("设备名称"));
            xpjReportDataDto.setDeviceType(sites.get("设备类型"));
            xpjReportDataDto.setCncType(sites.get("系统型号"));
            xpjReportDataDto.setNcVer(sites.get("系统版本"));
            xpjReportDataDto.setDeviceBrand(sites.get("设备品牌"));
            //设备变量统计
            EoStatistics eo = new EoStatistics();
            eo.setSb(deviceId);
            //1 redis和mqtt分开
            if (separate == 1) {
                //2 redis和mqtt统一
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.xpjSendString(comparison, deviceId, xpjReportDataDto, reportDto);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
                    Thread.sleep(sleepTime);
                }
            } else if (separate == 2) {
                //3 只发送redis
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.xpjSendString(comparison, deviceId, xpjReportDataDto, reportDto);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
                    Thread.sleep(sleepTime);
                }
            } else if (separate == 3) {
                //4 只发送mqtt
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.xpjSendString(comparison, deviceId, xpjReportDataDto, reportDto);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
                    eoStatisticsService.isFlag(objectMap,eo);
                    Thread.sleep(sleepTime);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    /**
     * 板链线
     * @param txtFile
     * @param skFileUrl
     * @param comparison
     * @param deviceId
     */
    public void blxStartLj(String txtFile, String skFileUrl, Map<String, String> comparison, String deviceId, XBMqttDataUtil xbMqttDataUtil) {
        try {
            //TODO 解析sk证书信息
            Map<String, Object> reportDto = resolveSk(skFileUrl);
            reportDto.put("productKey", "ConveMach");
            //实体类信息 从文件中查询基本信息
            Map<String, String> sites = readTxtFileToMap(txtFile);
            reportDto.put("clientUuid", sites.get("设备ID"));
            QtxlReportDataDto qtxlReportDataDto = new QtxlReportDataDto();

            qtxlReportDataDto.setDeviceID(sites.get("设备ID"));
            qtxlReportDataDto.setCompanyNo(sites.get("公司编码"));
            qtxlReportDataDto.setFactoryNo(sites.get("工厂编码"));
            qtxlReportDataDto.setAssetNo(sites.get("资产编码"));
            qtxlReportDataDto.setDeviceName(sites.get("设备名称"));
            qtxlReportDataDto.setDeviceType(sites.get("设备类型"));
            qtxlReportDataDto.setCncType(sites.get("系统型号"));
            qtxlReportDataDto.setNcVer(sites.get("系统版本"));
            qtxlReportDataDto.setDeviceBrand(sites.get("设备品牌"));
            //统计设备状态
            EoStatistics eo = new EoStatistics();
            eo.setSb(deviceId);
            //1 redis和mqtt分开
            if (separate == 1) {
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.qtxlSendString(comparison, deviceId, qtxlReportDataDto, reportDto);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
                    Thread.sleep(sleepTime);
                }
            } else if (separate == 2) {
                //2 redis和mqtt统一
                //3 只发送redis
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.qtxlSendString(comparison, deviceId, qtxlReportDataDto, reportDto);
                    StaticData.data.put(deviceId, objectMap);
                    eoStatisticsService.isFlag(objectMap,eo);
                    Thread.sleep(sleepTime);
                }
            } else if (separate == 3) {
                while (true) {
                    Map<String, Object> objectMap = base64decrypt.qtxlSendString(comparison, deviceId, qtxlReportDataDto, reportDto);
                    String json = new Gson().toJson(objectMap);
                    xbMqttDataUtil.publish(json);
                    eoStatisticsService.isFlag(objectMap,eo);
                    Thread.sleep(sleepTime);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }


    /**
     * 解析sk文件并且放入map集合中固定的
     *
     * @param skFileUrl
     * @return
     */
    public Map<String, Object> resolveSk(String skFileUrl) {
        Map<String, Object> skReportDto = new HashMap<>();
        String skFileValue = readSkFileToList(skFileUrl);
        if (skFileValue.isEmpty()) {
            return skReportDto;
        }
        JSONObject jsonObject = JSONObject.parseObject(skFileValue);
        skReportDto.put("cmdId", "10");
        skReportDto.put("version", jsonObject.getInteger("version"));
        skReportDto.put("sequenceId", 1);
        return skReportDto;
    }

//
//    /**
//     * 解析sk文件并且放入map集合中固定的
//     *
//     * @param skFile
//     * @return
//     */
//    public Map<String, Object> skReportDto(String skFile) {
//        String skFileValue = readSkFileToList(skFile);
//        JSONObject jsonObject = JSONObject.parseObject(skFileValue);
//        Map<String, Object> skReportDto = new HashMap<>();
//        skReportDto.put("cmdId", "10");
//        skReportDto.put("version", jsonObject.getInteger("version"));
//        skReportDto.put("sequenceId", 1);
//        skReportDto.put("edgeTime", Calendar.getInstance().getTimeInMillis());
//        return skReportDto;
//    }
    /**
     * reported对应的信息
     */


    /**
     * 获取证书sk解析后的码
     *
     * @return
     */
    public String readSkFileToList(String skFileUrl) {
        List<String> filelist = new ArrayList();
       // if (flag) {  //true读取jar包同级的路径
         //   filelist = readJarSkFile(skFileUrl);
       // } else {  //false读取resources下的路径
            filelist = readResourcesSkFile(skFileUrl);
       // }
        String info = "";

        if (filelist.isEmpty()) {
            return null;
        }
        // 遍历listStr集合
        for (String data : filelist) {
            // +换行
            info = info + data;
        }
        Base64.Decoder decoder = Base64.getDecoder();
        byte[] bytes = decoder.decode(info);
        return new String(bytes);
    }

    /**
     * 解析txt文件
     *
     * @param txtFileUrl
     * @return
     */
    public Map<String, String> readTxtFileToMap(String txtFileUrl) {
        HashMap<String, String> sites = new HashMap<>();
        List<String> txtFilelist = new ArrayList();
        if (flag) {
            txtFilelist = readJarSkFile(txtFileUrl);
        } else {
            txtFilelist = readResourcesSkFile(txtFileUrl);
        }
        if (txtFilelist.isEmpty()) {
            return sites;
        }
        for (String data : txtFilelist) {
            String[] split = data.split("=");
            if (split.length == 2) {
                sites.put(split[0], split[1]);
            } else {
                sites.put(split[0], "");
            }

        }
        return sites;
    }

//    public Map<String, String> readFileToMap(String txtFile) {
//        HashMap<String, String> sites = new HashMap<>();
//        List<String> txtFilelist = returnfilelist(txtFile);
//        for (int i = 0; i < txtFilelist.size(); i++) {
//            if (i > 1) {
//                String[] split = txtFilelist.get(i).split(" ");
//                sites.put(split[0], split[1]);
//            }
//        }
//
//        return sites;
//    }

//    /**
//     * 解析文件中的内容
//     *
//     * @param
//     * @return
//     */
//    public List<String> filelist(String path) {
//        List<String> listStr = new ArrayList<>();
//        BufferedReader br;
//        String str;
//        try {
//            br = new BufferedReader(new InputStreamReader(new FileInputStream(path), "UTF-8"));
//            while ((str = br.readLine()) != null) {
//                listStr.add(str);
//            }
//        } catch (FileNotFoundException e) {
//            e.printStackTrace();
//        } catch (IOException e) {
//            e.printStackTrace();
//        }
//        return listStr;
//    }

    public List<String> readResourcesSkFile(String skFileUrl) {
        List<String> listStr = new ArrayList<>();
        BufferedReader br;
        String str;
        try {
            ClassPathResource cpr = new ClassPathResource(skFileUrl);
            InputStream is = cpr.getInputStream();

            br = new BufferedReader(new InputStreamReader(is, "UTF-8"));
            while ((str = br.readLine()) != null) {
                listStr.add(str);
            }
        } catch (Exception e) {
            return listStr;
        }
        return listStr;
    }

    public List<String> readJarSkFile(String skFileUrl) {
        List<String> listStr = new ArrayList<>();
        String url = System.getProperty("user.dir");
        BufferedReader br;
        try {
            br = new BufferedReader(new InputStreamReader(new FileInputStream(url + skFileUrl), "UTF-8"));
            String tempStr;
            while ((tempStr = br.readLine()) != null) {
                listStr.add(tempStr);
            }
        } catch (Exception e) {
            return listStr;
        }
        return listStr;
    }

    /**
     * 机器人测试
     * @param txtFileUrl     静态文件路径
     * @param skFileUrl      sk文件路径
     * @param comparison     scada中配置的点位
     * @param deviceId       设备标识
     */
    public void jqr(String txtFileUrl, String skFileUrl, Map<String, String> comparison, String deviceId, XBMqttDataUtil xbMqttDataUtil) {
        try {
            //TODO 解析sk证书信息
            Map<String, Object> reportDto = resolveSk(skFileUrl);
            reportDto.put("productKey", "PaintRobot"); // TODO 上报到客户那边数据中必要的参数值
            //解析设备txt文本获取静态属性值
            Map<String, String> sites = readTxtFileToMap(txtFileUrl);
            Jqr jgReportDataDto = new Jqr();
            if (!sites.isEmpty()) {
                reportDto.put("clientUuid", sites.get("设备ID"));  //TODO 上报到客户那边数据中必要的参数值
                jgReportDataDto.setDeviceID(sites.get("设备ID"));
                jgReportDataDto.setCompanyNo(sites.get("公司编码"));
                jgReportDataDto.setFactoryNo(sites.get("工厂编码"));
                jgReportDataDto.setDeviceName(sites.get("设备名称"));
                jgReportDataDto.setDeviceType(sites.get("设备类型"));
            }
            //1 redis和mqtt分开
            if (separate == 1) {
                //TODO 同时MQTT上报和推送前端数据
                Map<String, Object> objectMap = base64decrypt.jqrSendString(comparison, deviceId, jgReportDataDto, reportDto);
                StaticData.data.put(deviceId, objectMap);
                String json = new Gson().toJson(objectMap);
                xbMqttDataUtil.publish( json);
            } else if (separate == 2) {
                // TODO  只推送前端数据
                Map<String, Object> objectMap = base64decrypt.jqrSendString(comparison, deviceId, jgReportDataDto, reportDto);
                StaticData.data.put(deviceId, objectMap);
            } else if (separate == 3) {
                //TODO  只发送mqtt
                Map<String, Object> objectMap = base64decrypt.jqrSendString(comparison, deviceId, jgReportDataDto, reportDto);
                String json = new Gson().toJson(objectMap);
                xbMqttDataUtil.publish(json);
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

}
